@@ -1,4 +1,4 @@
-from datetime import datetime
+import datetime
 from django.shortcuts import redirect, get_object_or_404
 from django.core.urlresolvers import reverse
 from django.conf import settings
@@ -219,7 +219,6 @@ def product(request, product=None):
         form = ProductForm(data)
 
     if form.is_valid():
-        print "FORM VALID"
         if product:
             form.save()
         else:
@@ -259,13 +258,15 @@ def product(request, product=None):
             i += 1
         return HttpResponseRedirect(
             reverse('luxuryadmin:product', kwargs={
-                'product': product.id
+                'product': product.id,
             })
         )
 
+    today = datetime.date.today().strftime('%d/%m/%Y')
     return TemplateResponse(request, 'luxuryadmin/product.html', dict(
         form_new_product=form,
         product=product,
+        today=today,
     ))
 
 
@@ -355,8 +356,9 @@ def xhr_save_product(request, pk=None, type=None):
         if not pk:
             product.slug = slugify(request.POST['name'])
             product.num_views = 0
-            product.in_date = datetime.now()
-
+            product.in_date = datetime.datetime.now()
+        if product.sold and not product.sold_date:
+            product.sold = datetime.date.today()
         product.live = True
         product.save()
 
